==> imforge-0.1.1.tar.gz: imforge-0.1.1/README.md <==
# ImForge

## Images Forge

ImForge is a library containing high level functionalities for manipulation of images, on top of Pillow (and OpenCv).

[![Lint](https://github.com/antoinehumbert/imforge/actions/workflows/lint.yml/badge.svg)](https://github.com/antoinehumbert/imforge/actions/workflows/lint.yml)
[![Test](https://github.com/antoinehumbert/imforge/actions/workflows/test.yml/badge.svg)](https://github.com/antoinehumbert/imforge/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/antoinehumbert/imforge/branch/develop/graph/badge.svg?token=90FVQSXYS9&flag=GHA_Ubuntu)](https://codecov.io/gh/antoinehumbert/imforge)
[![Build + Deploy](https://github.com/antoinehumbert/imforge/actions/workflows/build.yml/badge.svg)](https://github.com/antoinehumbert/imforge/actions/workflows/build.yml)
[![PyPI](https://img.shields.io/pypi/v/imforge)](https://pypi.org/project/imforge/)
[![Documentation Status](https://readthedocs.org/projects/imforge/badge/?version=latest)](https://imforge.readthedocs.io/en/latest/?badge=latest)

## Overview

The ImForge library provides a variety of high level functionalities empowering the manipulation of images in Python.

It works on Pillow images, and used some functions of OpenCv for advanced processing.

## More information

- [Documentation](https://imforge.readthedocs.io/)
- Contribute
  - [Issues](https://github.com/antoinehumbert/imforge/issues)
  - [Pull requests](https://github.com/antoinehumbert/imforge/pulls)
- [Changelog](https://github.com/antoinehumbert/imforge/blob/master/CHANGES.rst)

==> imforge-0.2.0.tar.gz: imforge-0.2.0/README.md <==
# ImForge

## Images Forge

ImForge is a library containing high level functionalities for manipulation of images, on top of Pillow, and OpenCv.

[![Lint](https://github.com/antoinehumbert/imforge/actions/workflows/lint.yml/badge.svg)](https://github.com/antoinehumbert/imforge/actions/workflows/lint.yml)
[![Test](https://github.com/antoinehumbert/imforge/actions/workflows/test.yml/badge.svg)](https://github.com/antoinehumbert/imforge/actions/workflows/test.yml)
[![codecov](https://codecov.io/gh/antoinehumbert/imforge/branch/develop/graph/badge.svg?token=90FVQSXYS9&flag=GHA_Ubuntu)](https://codecov.io/gh/antoinehumbert/imforge)
[![Build + Deploy](https://github.com/antoinehumbert/imforge/actions/workflows/build.yml/badge.svg)](https://github.com/antoinehumbert/imforge/actions/workflows/build.yml)
[![PyPI](https://img.shields.io/pypi/v/imforge.svg)](https://pypi.org/project/imforge/)
[![Documentation Status](https://readthedocs.org/projects/imforge/badge/?version=latest)](https://imforge.readthedocs.io/en/latest/?badge=latest)

## Overview

The ImForge library provides a variety of high level functionalities empowering the manipulation of images in Python.

It works on Pillow images as well as OpenCv images (i.e. numpy arrays).

## More information

- [Documentation](https://imforge.readthedocs.io/)
- Contribute
  - [Issues](https://github.com/antoinehumbert/imforge/issues)
  - [Pull requests](https://github.com/antoinehumbert/imforge/pulls)
- [Changelog](https://github.com/antoinehumbert/imforge/blob/master/CHANGES.rst)
